@@ -65,6 +65,7 @@ static char* crash_db_url = NULL;
 static const char* username = "whoopsie";
 
 /*  The database identifier. Either:
+ *  - The android serial number, taken from sys, and SHA-512 hashed
  *  - The system UUID, taken from the DMI tables and SHA-512 hashed
  *  - The MAC address of the first non-loopback device, SHA-512 hashed */
 static char* whoopsie_identifier = NULL;
@@ -993,9 +994,11 @@ main (int argc, char** argv)
                                                whoopsie_identifier);
     }
 
-    /* Publish whoopsie-id */
-    g_file_set_contents (WHOOPSIE_ID_PATH, whoopsie_identifier, -1, NULL);
-    chmod (WHOOPSIE_ID_PATH, 00600);
+    /* Only publish whoopsie-id if it was generated. LP: #1389357 */
+    if (env == NULL) {
+        g_file_set_contents (WHOOPSIE_ID_PATH, whoopsie_identifier, -1, NULL);
+        chmod (WHOOPSIE_ID_PATH, 00600);
+    }
 
     create_crash_directory ();
 
